<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage OfficePress Pro
 * @since OfficePress Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'officepress_pro_about_section', array(
	'title'             => esc_html__( 'About Us','officepress-pro' ),
	'description'       => esc_html__( 'About Section options.', 'officepress-pro' ),
	'panel'             => 'officepress_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'officepress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new OfficePress_Pro_Switch_Control( $wp_customize, 'officepress_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'officepress-pro' ),
	'section'           => 'officepress_pro_about_section',
	'on_off_label' 		=> officepress_pro_switch_options(),
) ) );

// About number control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[about_count]', array(
	'default'          	=> $options['about_count'],
	'sanitize_callback' => 'officepress_pro_sanitize_number_range',
	'validate_callback' => 'officepress_pro_validate_about_count',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[about_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'officepress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'officepress-pro' ),
	'section'           => 'officepress_pro_about_section',
	'active_callback'   => 'officepress_pro_is_about_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// About content type control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'officepress_pro_sanitize_select',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'officepress-pro' ),
	'section'           => 'officepress_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'officepress_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'officepress-pro' ),
		'post' 		=> esc_html__( 'Post', 'officepress-pro' ),
		'category' 	=> esc_html__( 'Category', 'officepress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['about_count']; $i++ ) :
	// About btn title setting and control
	$wp_customize->add_setting( 'officepress_pro_theme_options[about_sub_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'officepress_pro_theme_options[about_sub_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Sub Title %d', 'officepress-pro' ), $i ),
		'section'        	=> 'officepress_pro_about_section',
		'active_callback' 	=> 'officepress_pro_is_about_section_enable',
		'type'				=> 'text',
	) );

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'officepress_pro_theme_options[about_content_page_' . $i . ']', array(
		'sanitize_callback' => 'officepress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new OfficePress_Pro_Dropdown_Chooser( $wp_customize, 'officepress_pro_theme_options[about_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'officepress-pro' ), $i ),
		'section'           => 'officepress_pro_about_section',
		'choices'			=> officepress_pro_page_choices(),
		'active_callback'	=> 'officepress_pro_is_about_section_content_page_enable',
	) ) );

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'officepress_pro_theme_options[about_content_post_' . $i . ']', array(
		'sanitize_callback' => 'officepress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new OfficePress_Pro_Dropdown_Chooser( $wp_customize, 'officepress_pro_theme_options[about_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'officepress-pro' ), $i ),
		'section'           => 'officepress_pro_about_section',
		'choices'			=> officepress_pro_post_choices(),
		'active_callback'	=> 'officepress_pro_is_about_section_content_post_enable',
	) ) );

	// about hr setting and control
	$wp_customize->add_setting( 'officepress_pro_theme_options[about_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new OfficePress_Pro_Customize_Horizontal_Line( $wp_customize, 'officepress_pro_theme_options[about_hr_'. $i .']',
		array(
			'section'         => 'officepress_pro_about_section',
			'active_callback' => 'officepress_pro_is_about_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'officepress_pro_theme_options[about_content_category]', array(
	'sanitize_callback' => 'officepress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new OfficePress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'officepress_pro_theme_options[about_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'officepress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'officepress-pro' ),
	'section'           => 'officepress_pro_about_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'officepress_pro_is_about_section_content_category_enable'
) ) );


// About btn title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
) );

$wp_customize->add_control( 'officepress_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_about_section',
	'active_callback' 	=> 'officepress_pro_is_about_section_enable',
	'type'				=> 'text',
) );
