<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage OfficePress Pro
 * @since OfficePress Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'officepress_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','officepress-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'officepress-pro' ),
	'panel'             => 'officepress_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'officepress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new OfficePress_Pro_Switch_Control( $wp_customize, 'officepress_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'officepress-pro' ),
	'section'           => 'officepress_pro_blog_section',
	'on_off_label' 		=> officepress_pro_switch_options(),
) ) );

// blog sub title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_blog_section',
	'active_callback' 	=> 'officepress_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[blog_sub_title]', array(
		'selector'            => '#latest-posts .section-header p.section-subtitle',
		'settings'            => 'officepress_pro_theme_options[blog_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_blog_sub_title_partial',
    ) );
}

// blog title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_blog_section',
	'active_callback' 	=> 'officepress_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[blog_title]', array(
		'selector'            => '#latest-posts .section-header h2.section-title',
		'settings'            => 'officepress_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_blog_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'officepress_pro_sanitize_number_range',
	'validate_callback' => 'officepress_pro_validate_blog_count',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'officepress-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'officepress-pro' ),
	'section'           => 'officepress_pro_blog_section',
	'active_callback'   => 'officepress_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Blog content type control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'officepress_pro_sanitize_select',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'officepress-pro' ),
	'section'           => 'officepress_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'officepress_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'officepress-pro' ),
		'post' 		=> esc_html__( 'Post', 'officepress-pro' ),
		'category' 	=> esc_html__( 'Category', 'officepress-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'officepress-pro' ),
	),
) );


for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'officepress_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'officepress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new OfficePress_Pro_Dropdown_Chooser( $wp_customize, 'officepress_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'officepress-pro' ), $i ),
		'section'           => 'officepress_pro_blog_section',
		'choices'			=> officepress_pro_page_choices(),
		'active_callback'	=> 'officepress_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'officepress_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'officepress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new OfficePress_Pro_Dropdown_Chooser( $wp_customize, 'officepress_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'officepress-pro' ), $i ),
		'section'           => 'officepress_pro_blog_section',
		'choices'			=> officepress_pro_post_choices(),
		'active_callback'	=> 'officepress_pro_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'officepress_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'officepress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new OfficePress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'officepress_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'officepress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'officepress-pro' ),
	'section'           => 'officepress_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'officepress_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'officepress_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new OfficePress_Pro_Dropdown_Category_Control( $wp_customize,'officepress_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'officepress-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'officepress-pro' ),
	'section'           => 'officepress_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'officepress_pro_is_blog_section_content_recent_enable'
) ) );

// blog btn title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_readmore_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_readmore_title'],
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_readmore_title]', array(
	'label'           	=> esc_html__( 'Read More Label', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_blog_section',
	'active_callback' 	=> 'officepress_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// blog btn title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_blog_section',
	'active_callback' 	=> 'officepress_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[blog_btn_title]', array(
		'selector'            => '#latest-posts .read-more.button a.btn',
		'settings'            => 'officepress_pro_theme_options[blog_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_blog_btn_title_partial',
    ) );
}

// blog btn title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[blog_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[blog_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_blog_section',
	'active_callback' 	=> 'officepress_pro_is_blog_section_enable',
	'type'				=> 'url',
) );