<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage OfficePress Pro
 * @since OfficePress Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'officepress_pro_featured_section', array(
	'title'             => esc_html__( 'Featured Projects','officepress-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'officepress-pro' ),
	'panel'             => 'officepress_pro_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'officepress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new OfficePress_Pro_Switch_Control( $wp_customize, 'officepress_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'officepress-pro' ),
	'section'           => 'officepress_pro_featured_section',
	'on_off_label' 		=> officepress_pro_switch_options(),
) ) );

// Featured sub title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[featured_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_featured_section',
	'active_callback' 	=> 'officepress_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[featured_sub_title]', array(
		'selector'            => '#our-projects .section-header .section-subtitle',
		'settings'            => 'officepress_pro_theme_options[featured_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_featured_sub_title_partial',
    ) );
}

// Featured title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_featured_section',
	'active_callback' 	=> 'officepress_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[featured_title]', array(
		'selector'            => '#our-projects .section-header h2.section-title',
		'settings'            => 'officepress_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_featured_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'officepress_pro_sanitize_number_range',
	'validate_callback' => 'officepress_pro_validate_featured_count',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'officepress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'officepress-pro' ),
	'section'           => 'officepress_pro_featured_section',
	'active_callback'   => 'officepress_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'officepress_pro_sanitize_select',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'officepress-pro' ),
	'section'           => 'officepress_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'officepress_pro_is_featured_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'officepress-pro' ),
		'post' 		=> esc_html__( 'Post', 'officepress-pro' ),
		'category' 	=> esc_html__( 'Category', 'officepress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_count']; $i++ ) :
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'officepress_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'officepress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new OfficePress_Pro_Dropdown_Chooser( $wp_customize, 'officepress_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'officepress-pro' ), $i ),
		'section'           => 'officepress_pro_featured_section',
		'choices'			=> officepress_pro_page_choices(),
		'active_callback'	=> 'officepress_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'officepress_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'officepress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new OfficePress_Pro_Dropdown_Chooser( $wp_customize, 'officepress_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'officepress-pro' ), $i ),
		'section'           => 'officepress_pro_featured_section',
		'choices'			=> officepress_pro_post_choices(),
		'active_callback'	=> 'officepress_pro_is_featured_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'officepress_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'officepress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new OfficePress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'officepress_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'officepress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'officepress-pro' ),
	'section'           => 'officepress_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'officepress_pro_is_featured_section_content_category_enable'
) ) );


// Featured btn title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[featured_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_featured_section',
	'active_callback' 	=> 'officepress_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[featured_btn_title]', array(
		'selector'            => '#our-projects .read-more a.btn',
		'settings'            => 'officepress_pro_theme_options[featured_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_featured_btn_title_partial',
    ) );
}

// Featured btn url setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[featured_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[featured_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_featured_section',
	'active_callback' 	=> 'officepress_pro_is_featured_section_enable',
	'type'				=> 'url',
) );
