<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage OfficePress Pro
 * @since OfficePress Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'officepress_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','officepress-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'officepress-pro' ),
	'panel'             => 'officepress_pro_front_page_panel',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'officepress_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'officepress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new OfficePress_Pro_Switch_Control( $wp_customize, 'officepress_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'officepress-pro' ),
	'section'           => 'officepress_pro_subscription_section',
	'on_off_label' 		=> officepress_pro_switch_options(),
) ) );

// subscription description setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[subscription_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[subscription_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_subscription_section',
	'active_callback' 	=> 'officepress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[subscription_subtitle]', array(
		'selector'            => '#subscribe-now .section-header p',
		'settings'            => 'officepress_pro_theme_options[subscription_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_subscription_subtitle_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'officepress_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_subscription_section',
	'active_callback' 	=> 'officepress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'officepress_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now .section-header h2.section-title',
		'settings'            => 'officepress_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'officepress_pro_subscription_title_partial',
    ) );
}

// subscription image setting and control.
$wp_customize->add_setting( 'officepress_pro_theme_options[subscription_image]', array(
	'sanitize_callback' => 'officepress_pro_sanitize_image',
	'default'			=> $options['subscription_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'officepress_pro_theme_options[subscription_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'officepress-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'officepress-pro' ), 1280, 854 ),
		'section'     		=> 'officepress_pro_subscription_section',
		'active_callback'	=> 'officepress_pro_is_subscription_section_enable',
) ) );

// subscription btn title setting and control
$wp_customize->add_setting( 'officepress_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'officepress_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'officepress-pro' ),
	'section'        	=> 'officepress_pro_subscription_section',
	'active_callback' 	=> 'officepress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

