<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage OfficePress Pro
 * @since OfficePress Pro 1.0.0
 */
if ( ! function_exists( 'officepress_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since OfficePress Pro 1.0.0
    */
    function officepress_pro_add_featured_section() {
    	$options = officepress_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'officepress_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'officepress_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        officepress_pro_render_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'officepress_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since OfficePress Pro 1.0.0
    * @param array $input featured section details.
    */
    function officepress_pro_get_featured_section_details( $input ) {
        $options = officepress_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 4;
        
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = officepress_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'officepress_pro_filter_featured_section_details', 'officepress_pro_get_featured_section_details' );


if ( ! function_exists( 'officepress_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since OfficePress Pro 1.0.0
   *
   */
   function officepress_pro_render_featured_section( $content_details = array() ) {
        $options = officepress_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-projects" class="relative page-section">
            <div class="wrapper">

                <?php if ( ! empty( $options['featured_title'] ) || ! empty( $options['featured_sub_title'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['featured_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['featured_sub_title'] ); ?></p>
                        <?php endif; 

                        if ( ! empty( $options['featured_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ); ?></h2>
                        <?php endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="project-slider modern-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( 'page' !== $featured_content_type ) : ?>
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                    </div><!-- .entry-meta -->
                                <?php endif; ?>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                    
                </div><!-- .project-slider -->

                <?php if ( ! empty( $options['featured_btn_title'] ) && ! empty( $options['featured_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['featured_btn_url'] ); ?>" class="btn"><?php echo esc_html( $options['featured_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #our-projects -->

    <?php }
endif;